# encoding: utf-8
# SPDX-License-Identifier: LGPL-3.0-or-later

"""
A tiny compatibility module for cross-Python2/3 code.
"""

from .__dataclass_attrs import *
from .__str import *


__version_info__ = (1, 0, 2)
__version__ = ".".join(str(x) for x in __version_info__)

__url__ = "https://github.com/Lex-DRL/darlog-py23"
__uri__ = __url__

__author__ = 'Lex Darlog (Lex-DRL)'

__license__ = "LGPL-3.0-or-later"
__copyright__ = "Copyright (c) 2022 Lex Darlog"



# encoding: utf-8
# SPDX-License-Identifier: LGPL-3.0-or-later

"""
"""

import sys as _sys

try:
	import typing as _t
except ImportError:
	pass


def to_least_str(val):
	# type: (...) -> _t.AnyStr
	"""
	Python 2:
		* Try to convert to `str()`. If fails, convert to `unicode()`.
		*
			For custom classes inherited from either of them, try to preserve it
			(`unicode` subclass might be converted to regular `str` if possible).

	Python 3:
		Just an alias for `str()`.
	"""
	if isinstance(val, str):
		return val

	# noinspection PyBroadException
	try:
		return str(val)
	except Exception:
		if isinstance(val, unicode):
			return val
		return unicode(val)


PY3 = _sys.version_info[0] == 3

if PY3:
	to_least_str = str



# encoding: utf-8
# SPDX-License-Identifier: MIT

"""
Copyright (c) 2015 Hynek Schlawack
License: MIT

This module contains copies of some essential functions from the ``attrs`` package.
They're used to make ``dataclass`` fallback behave similarly to ``attrs``.
"""

__url__ = "https://www.attrs.org/"
__uri__ = __url__
__author__ = "Hynek Schlawack"
__license__ = "MIT"
__copyright__ = "Copyright (c) 2015 Hynek Schlawack"


def _determine_attrs_eq_order(cmp, eq, order, default_eq):
	"""
	Validate the combination of *cmp*, *eq*, and *order*. Derive the effective
	values of eq and order.  If *eq* is None, set it to *default_eq*.
	"""
	if cmp is not None and any((eq is not None, order is not None)):
		raise ValueError("Don't mix `cmp` with `eq' and `order`.")

	# cmp takes precedence due to bw-compatibility.
	if cmp is not None:
		return cmp, cmp

	# If left None, equality is set to the specified default and ordering
	# mirrors equality.
	if eq is None:
		eq = default_eq

	if order is None:
		order = eq

	if eq is False and order is True:
		raise ValueError("`order` can only be True if `eq` is True too.")

	return eq, order



#!/usr/bin/env python
# encoding: utf-8

"""
https://packaging.python.org/en/latest/guides/distributing-packages-using-setuptools/#setup-args
"""

import codecs
from os import path
import sys

from setuptools import find_packages, setup

HERE = path.abspath(path.dirname(__file__))
SRC_DIR = "src"

sys.path.append(path.join(HERE, SRC_DIR))

import darlog_py23 as the_module


NAME = "darlog-py23"
KEYWORDS = ["2to3", "3to2", "six", "compatibility", "wrapper"]
CLASSIFIERS = [
	# https://pypi.org/classifiers/
	"Development Status :: 5 - Production/Stable",
	"Intended Audience :: Developers",
	"License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)",
	"Natural Language :: English",
	"Operating System :: OS Independent",
	"Programming Language :: Python",
	"Programming Language :: Python :: 2",
	"Programming Language :: Python :: 2.7",
	"Programming Language :: Python :: 3",
	"Programming Language :: Python :: 3.7",
	"Programming Language :: Python :: 3.8",
	"Programming Language :: Python :: 3.9",
	"Programming Language :: Python :: 3.10",
	"Topic :: Software Development :: Libraries :: Python Modules",
	"Typing :: Typed",
]
PYTHON_REQUIRES = ">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*, !=3.5.*, !=3.6.*, <4"
INSTALL_REQUIRES = [
	# "six",
]
EXTRAS_REQUIRE = {
	"dev": ["attrs"],
}


def read_utf8(*parts):
	"""
	Copyright (c) 2015 Hynek Schlawack
	License: MIT

	Utility function borrowed from ``attrs`` package.

	Build an absolute path from *parts* and return the contents of the resulting file.
	"""
	with codecs.open(path.join(HERE, *parts), "rb", encoding="utf-8") as f:
		return f.read()


LONG_DESC = read_utf8("README.md")
SHORT_DESC = the_module.__doc__.strip()


if __name__ == '__main__':
	setup(
		name=NAME,
		version=the_module.__version__,
		description=SHORT_DESC,
		long_description=LONG_DESC,
		long_description_content_type="text/markdown",
			# https://packaging.python.org/en/latest/specifications/core-metadata/#description-content-type-optional

		url=the_module.__url__,
		author=the_module.__author__,
		maintainer=the_module.__author__,
		license=the_module.__license__,

		classifiers=CLASSIFIERS,
		keywords=KEYWORDS,

		package_dir={"": SRC_DIR},
		packages=find_packages(where=SRC_DIR),
		python_requires=PYTHON_REQUIRES,
		install_requires=INSTALL_REQUIRES,
		extras_require=EXTRAS_REQUIRE,
	)
